/**********************************************
 THIS COMMAND FILE READS IN THE AFIFI DATA SET
 AND SETS UP THE FORMATS FOR THE VARIABLES

FILENAME: AFIFI.SAS
***********************************************/

TITLE1 "INTRODUCTION TO SAS WORKSHOP";
LIBNAME SASDATA2 V9 "c:\temp\sasdata2\";
LIBNAME LIBRARY "c:\temp\sasdata2\";
OPTIONS FMTSEARCH=(WORK LIBRARY);

DATA SASDATA2.AFIFI;
    INFILE "afifi.dat";
    INPUT
    #1 IDNUM 1-4 AGE 5-8 SEX 13-15 SURVIVE 16 SHOKTYPE 17-20 SBP1 21-24
       MAP1 25-28 HEART1 29-32 CARDIAC1 45-48 2 URINE1 57-60 HGB1 69-72 1
    #2 SBP2 21-24 MAP2 25-28 HEART2 29-32 CARDIAC2 45-48 2 URINE2 57-60
       HGB2 69-72 1;

    LABEL SHOCK="Shock type"
       SBP1="Systolic BP at time 1"
       SBP2="Systolic BP at time 2"
       MAP1="Mean arterial pressure at time 1"
       MAP2="Mean arterial pressure at time 2"
       HEART1="Heart rate at time 1"
       HEART2="Heart rate at time 2"
       CARDIAC1="Cardiac index at time 1"
       CARDIAC2="Cardiac index at time 2"
       URINE1="Urinary output at time 1"
       URINE2="Urinary output at time 2"
       HGB1="Hemoglobin at time 1"
       HGB2="Hemoglobin at time 2" ;

    IF SHOKTYPE=2 THEN SHOCK=1;
    IF SHOKTYPE IN (3,4,5,6,7) THEN SHOCK=2;
    IF SURVIVE=1 THEN DIED=0;
    IF SURVIVE=3 THEN DIED=1;
    SBPDIFF=SBP2-SBP1;
    LABEL SHOCK="Binary Shock"; RUN;
PROC FORMAT LIB=LIBRARY ;
    VALUE SEXFMT   1="1: Male" 2="2: Female" ;
    VALUE SURVFMT  1="1: Lived" 3="3: Died" ;
    VALUE SHKTYFMT 2="2: Non-Shock" 
	              3="3: Hypovolemic"
			   4="4: Cardiogenic"
			   5="5: Bacterial"
			   6="6: Neurogenic"
			   7="7: Other";
    VALUE SHOCKFMT 1="1: No shock" 2="2: Shock" ;
RUN;

PROC DATASETS LIB=SASDATA2;
    MODIFY AFIFI;
    FORMAT SEX SEXFMT. SURVIVE SURVFMT. 
	       SHOKTYPE SHKTYFMT. SHOCK SHOCKFMT.;
RUN;
PROC CONTENTS DATA=SASDATA2.AFIFI;
RUN;

