/***************************************************************
  Use a retain statement with a modify statement, to rearrange
  the order of variables in a data set
 
  Filename: changeord.sas
****************************************************************/
OPTIONS FORMCHAR="|----|+|---+=|-/\<>*";

DATA AFIFI;
    INFILE "AFIFI.DAT";
    INPUT
    #1 IDNUM 1-4 AGE 5-8 SEX 13-15 SURVIVE 16 SHOKTYPE 17-20 SBP1 21-24
       MAP1 25-28 HEART1 29-32 CARDIAC1 45-48 2 URINE1 57-60 HGB1 69-72 1
    #2 SBP2 21-24 MAP2 25-28 HEART2 29-32 CARDIAC2 45-48 2 URINE2 57-60
       HGB2 69-72 1;

    LABEL 
	   SURVIVE="Survived or Not"
       SHOCK="In Shock or Not"
       SBP1="Systolic BP at time 1"
       SBP2="Systolic BP at time 2"
       MAP1="Mean arterial pressure at time 1"
       MAP2="Mean arterial pressure at time 2"
       HEART1="Heart rate at time 1"
       HEART2="Heart rate at time 2"
       CARDIAC1="Cardiac index at time 1"
       CARDIAC2="Cardiac index at time 2"
       URINE1="Urinary output at time 1"
       URINE2="Urinary output at time 2"
       HGB1="Hemoglobin at time 1"
       HGB2="Hemoglobin at time 2" ;

    IF SHOKTYPE=2 THEN SHOCK=1;
    IF SHOKTYPE IN (3,4,5,6,7) THEN SHOCK=2;
    SBPDIFF=SBP2-SBP1;
RUN;

data afifi;
  retain idnum survive sex;
  modify afifi;
run;
proc contents data=afifi varnum;
run;

/********************************************************************
  A safer way to do this is to create a new data set, rather
  than modifying the original AFIFI data set. First, we reread
  the raw data into SAS.
*********************************************************************/
DATA AFIFI;
    INFILE "AFIFI.DAT";
    INPUT
    #1 IDNUM 1-4 AGE 5-8 SEX 13-15 SURVIVE 16 SHOKTYPE 17-20 SBP1 21-24
       MAP1 25-28 HEART1 29-32 CARDIAC1 45-48 2 URINE1 57-60 HGB1 69-72 1
    #2 SBP2 21-24 MAP2 25-28 HEART2 29-32 CARDIAC2 45-48 2 URINE2 57-60
       HGB2 69-72 1;

    LABEL 
	   SURVIVE="Survived or Not"
       SHOCK="In Shock or Not"
       SBP1="Systolic BP at time 1"
       SBP2="Systolic BP at time 2"
       MAP1="Mean arterial pressure at time 1"
       MAP2="Mean arterial pressure at time 2"
       HEART1="Heart rate at time 1"
       HEART2="Heart rate at time 2"
       CARDIAC1="Cardiac index at time 1"
       CARDIAC2="Cardiac index at time 2"
       URINE1="Urinary output at time 1"
       URINE2="Urinary output at time 2"
       HGB1="Hemoglobin at time 1"
       HGB2="Hemoglobin at time 2" ;

    IF SHOKTYPE=2 THEN SHOCK=1;
    IF SHOKTYPE IN (3,4,5,6,7) THEN SHOCK=2;
    SBPDIFF=SBP2-SBP1;
RUN;

data afifi2;
  retain idnum survive sex;
  set afifi;
run;
proc contents data=afifi2 varnum;
run;


