/************************************************
 THIS COMMAND FILE ILLUSTRATES HOW TO COUNT 
 OBSERVATIONS IN A SAS DATA STEP.

 FILENAME: COUNT.SAS
*************************************************/
OPTIONS FORMCHAR="|----|+|---+=|-/\<>*";

options nodate pageno=1;
title;
/******************************************************
data catalina;
input site $ island	 siteno	 plant width	length1	length2	date;
cards;
CAT	1	1	1	5.87	10.36	29.71	1
CAT	1	1	1	5.90	9.52	31.13	1
CAT	1	1	1	6.20	8.77	30.80	1
CAT	1	1	1	6.40	9.78	31.05	1
CAT	1	1	1	6.55	9.00	28.54	1
CAT	1	1	1	7.07	7.83	26.85	1
CAT	1	1	1	7.35	7.77	26.22	1
CAT	1	1	1	7.62	8.88	28.59	1
CAT	1	1	2	4.92	7.59	27.75	1
CAT	1	1	2	6.19	9.03	29.06	1
CAT	1	1	2	6.21	8.62	28.29	1
CAT	1	1	2	6.34	8.87	28.08	1
CAT	1	1	2	6.53	8.20	28.30	1
CAT	1	1	2	6.62	8.95	27.79	1
CAT	1	1	3	6.03	8.06	25.89	1
CAT	1	1	3	6.18	7.79	27.15	1
CAT	1	1	3	6.43	8.03	28.51	1
CAT	1	1	3	7.09	9.52	27.73	1
CAT	1	1	3	7.48	8.39	25.88	1
CAT	1	1	4	5.92	8.24	24.94	1
CAT	1	1	4	5.96	7.32	26.17	1
CAT	1	1	4	5.31	7.32	26.5	6
CAT	1	1	4	5.48	8.09	26.93	6
CAT	1	1	4	5.61	8	    27.76	6
CAT	1	1	4	5.72	8.6	    27.21	6
CAT	1	1	4	5.79	8.71	26.56	6
CAT	1	1	4	5.98	9.15	28.14	6
CAT	1	1	4	6.5	    9.15	28.05	6
CAT	1	1	4	6.73	8.19	27.19	6
CAT	1	1	5	5.75	8.49	29.68	1
CAT	1	1	5	6.00	8.41	29.03	1
CAT	1	1	5	6.20	8.37	29.58	1
CAT	1	1	5	6.42	8.23	28.07	1
CAT	1	1	5	6.70	7.81	27.02	1
CAT	1	1	5	6.72	7.95	27.39	1
CAT	1	1	5	6.93	7.64	26.88	1
;
******************************************************/
PROC IMPORT OUT= WORK.catalina 
            DATAFILE= "flowerdata.xls" 
            DBMS=EXCEL REPLACE;
     SHEET="Flowerdata"; 
     GETNAMES=YES;
     MIXED=NO;
     SCANTEXT=YES;
     USEDATE=YES;
     SCANTIME=YES;
RUN;

/***********************************************
 KEEP A RUNNING COUNT OF THE FLOWER NUMBER
  FOR EACH PLANT, total n=771
***********************************************/
proc sort data=catalina;
  by siteno plant;
run;

data catalina2;
  set catalina;
  by siteno plant;
  retain flower 0;
  if first.plant then flower=0;
  flower=flower+1;
run;

proc print data=catalina2(obs=25);
title "Flower Counts";
run;


/*USING A SUM STATEMENT: A SIMPLER WAY TO COUNT WITHOUT USING RETAIN*/

data catalina2;
  set catalina;
  by siteno plant;

  if first.plant then flower=0;
  flower+1;
run;

proc print data=catalina2;
title "Flower Counts";
run;


/*NOW, JUST OUTPUT THE LAST OBSERVATION FOR EACH
  PLANT, SO WE HAVE THE TOTAL NUMBER OF FLOWERS
  FOR THAT PLANT n=82*/

proc sort data=catalina;
  by siteno plant;
run;

data catalina_plants;
  set catalina;

  by siteno plant;
  retain flower 0;

  if first.plant then flower=0;
  flower=flower+1;

  if last.plant then output;

run;

proc print data=catalina_plants;
title "Flower Counts";
run;

data catalina3;
  set catalina;
  by siteno plant;

  retain flower 0 avewidth totwidth 0;

  if first.plant then do;
   flower=0;
   avewidth=0;
  end;

    flower=flower+1;
	totwidth = totwidth + width;
	avewidth =  totwidth / flower;

	if last.plant then output;
run;

title "One Value per Flower";
proc print data=catalina3(obs=20);
run;

/*Calculate summary statistics for each plant using
  Proc Means*/
proc sort data=catalina;
  by siteno plant;
run;

proc means data=catalina noprint;
  by siteno plant;
  output out=meandat(rename=_freq_ = flower drop=_type_) 
         mean(width)=width_mean
         mean(length1)=length1_mean;
run;

title "Flower Meandat from Proc Means";
proc print data=meandat;
run;

