/********************************************
 THIS COMMAND FILE SHOWS EXAMPLES OF USING
 PROC DATASETS FOR MANAGING FILES AND
 LIBRARIES IN SAS.

 FILENAME: DATASETS.SAS
*********************************************/
OPTIONS FORMCHAR="|----|+|---+=|-/\<>*";
options nodate pageno=1;
title;

/**********************************************
 CREATE DATA TO USE IN EXAMPLES
***********************************************/
data pulse;
   infile "pulse.dat";
   input pulse1 pulse2 ran smokes sex height weight activity;
run;
data males females;
  set pulse;
  if sex=1 then output males;
  if sex=2 then output females;
run;

/**********************************************
 USE PROC DATASETS TO APPLY VARIABLE LABELS
 TO A DATASET
***********************************************/
proc datasets lib=work;
   modify pulse;
   label pulse1="Pulse at Time 1"
         pulse2="Pulse at Time 2"
         ran   ="Ran in Place?"
         height="Height(inches)"
         weight="Weight(pounds)"
         activity="Activity Level";
run; quit;

/****************************************************
 APPEND TWO DATASETS
****************************************************/
proc datasets ;
  append base=males data=females;
  run;
quit;

/****************************************************
 CHANGE THE NAME OF A DATASET
****************************************************/
proc datasets lib=work;
  change males=alldata;
  change pulse=heartrate;
run;quit;

/****************************************************
 COPY DATASETS FROM ONE LIBRARY TO ANOTHER
****************************************************/
libname sasdata1 v6 "C:\Documents and Settings\Kathy\Desktop\sasdata1";
libname sasdata2 v9 "C:\Documents and Settings\Kathy\Desktop\sasdata2";

proc datasets lib=sasdata2;
  copy in=sasdata1 out=sasdata2;
run;quit;


/*****************************************************
 TO RESTRICT THE COPYING TO DATASETS ONLY,
  USE MEMTYPE=DATA
 (EXCLUDES FORMATS CATALOGS)
******************************************************/

proc datasets memtype=data lib=sasdata2;
  copy in=sasdata1 out=sasdata2;
run;quit;

/*****************************************************
 TO RESTRICT THE COPYING TO CATALOGS ONLY,
  USE MEMTYPE=CATALOG
 (EXCLUDES DATA SETS)
******************************************************/

proc datasets  memtype=catalog lib=sasdata2;
  copy in=sasdata1 out=sasdata2;
run;quit;

/*****************************************************
 TO COPY ONLY SELECTED DATA SETS, USE A 
  SELECT STATEMENT.
******************************************************/
proc datasets lib=sasdata2;
  copy in=work out=sasdata2;
  select heartrate; 
run;quit;

/*****************************************************
 TO COPY EXCLUDE SELECTED DATA SETS, USE AN 
  EXCLUDE STATEMENT.
******************************************************/
proc datasets memtype=data lib=sasdata1;
  copy in=sasdata1 out=sasdata2;
  exclude gpa;
run;


/****************************************************
 DELETE DATASETS FROM A LIBRARY
****************************************************/
proc datasets lib=WORK;
  delete females;
run;quit;

/****************************************************
 KILL ALL DATASETS IN A LIBRARY
****************************************************/
proc datasets lib=WORK kill;
run;quit;


/****************************************************
 WORKING WITH FORMATS
****************************************************/
libname sasdata2 v9 "C:\Documents and Settings\Kathy\Desktop\sasdata2";
options FMTSEARCH=(WORK sasdata2);
options nofmterr;

proc format lib=sasdata2;
  value ranfmt 1="Ran" 2="Didn't Run";
  value sexfmt 1="Male" 2="Female";
  value actfmt 1="Low" 2="Medium" 3="High";
  value smkfmt 1="Smoker" 2="Non-Smoker";
run;

proc datasets lib=sasdata2;
  modify heartrate;
  format ran ranfmt. sex sexfmt. activity actfmt. smokes smkfmt.;
run;
proc contents data=sasdata2.heartrate;
run;
proc freq data=sasdata2.heartrate;
  tables ran sex;
run;

/******************************************
  To get a listing of the formats in a 
  formats catalog, use the fmtlib option 
  with Proc Format
*******************************************/
proc format lib=sasdata2 fmtlib;
run;

/******************************************
  To get a dataset containing the formats
  and their values, use the cntlout option 
  with Proc Format
*******************************************/
proc format lib=sasdata2 cntlout=formatdata;
run;
proc print data=formatdata;
run;

/******************************************
  To place the formats in your format dataset
  into a formats catalog, use the cntlin option.
*******************************************/
proc format lib=work cntlin = formatdata;
run;





