/************************************************                                                                                       
 THIS COMMAND FILE ILLUSTRATES SEVERAL EXAMPLES                                                                                         
 OF HOW SAS DATA SETS CAN BE CREATED USING                                                                                              
 INPUT, SET, MERGE OR UPDATE STATEMENTS                                                                                                 
                                                                                                                                        
 FILENAME: DATASTEP.SAS                                                                                                                 
*************************************************/                                                                                      
OPTIONS FORMCHAR="|----|+|---+=|-/\<>*";
                                                                                                                                       
/*Creating a SAS data set with an Input Statement*/                                                                                                   
data bp;
	infile "bp.dat";
	input  id sex $ age height weight sbp dbp;
wtkg = weight * .455;
htcm = height * 2.54;
bmi  = wtkg / ((htcm/100)**2 );
drop wtkg htcm;
run;
                                                                                                                           
proc print data=bp;                                                                                                                             
 title "BP Data Set: Created Using INPUT";                                                                                              
run;                                                                                                                                    

/*Try It: Write another data step to read in the same raw 
  data, but this time use a keep statement to keep
  only the variables ID, SEX, AGE, and BMI*/

 
/*Creating a SAS data set with a Set Statement*/                                                                                                             
                                                                                                                                        
data newbp;
  set bp;

  if age >= 20 and age < 30 then agegrp=1;
  if age >= 30 and age < 40 then agegrp=2;
  if age >= 40 and age < 50 then agegrp=3;
  if age >=50 then agegrp=4;

  if bmi > 25 then hibmi=1;
  else if 0 <=bmi <=25 then hibmi=0;

run;
 
                                                                                                                                        
title "NEWBP Data Set: Created Using SET";                                                                                            
proc print data=newbp;                                                                                                                             
run;                                                                                                                                    
                                                                                                                                        
/*Creating a SAS data set with a Merge Statement*/                                                                                              
data labvals;
  infile "labvalues.dat";
  input id hrtrate cardiac hemo;
run;  
proc sort data=newbp;
  by id;
run;
proc sort data=labvals;
  by id;
run;
data bplab;
  merge newbp labvals;
  by id;
run;


title "BPLAB Data Set: Created Using MERGE";                                                                                          
proc print data=bplab;                                                                                                                  
run;                                                                                                                                    
                                                                                                                                        
/*Updating values in a SAS data set with an Update Statement*/                                                                                                          
                                                                                                                                        
data transact;
  input id hrtrate hemo;
  cards;
  1 135 12.1
  4  .  14.0
  ;
data bplab_up;
 update bplab transact;
 by id;
run;
proc print data=bplab_up;
  title "BBLAB_UP Data Set: Created Using UPDATE";
run;                                                                                                                                    

/*Try It: Generate SAS commands to update the 
  dataset by updating the Cardiac value of
  ID 14 from 128 to 185 and their age from
  Missing to 52. 

  Also, update the age of ID
  8 from Missing to 47.*/                                                                                                          


 
/*A commonly encountered data step problem
  Note: this overwrites the data set, bplab_up 
  and creates a data set with Zero Observations!*/                                                                                            
                                                                                                                                        
data bplab_up;                                                                                                                          
run;


/*Try It: Regenerate your dataset called bplab_up*/
