/********************************************
 THIS COMMAND FILE SHOWS EXAMPLES OF USING
 SIMPLE DESCRIPTIVE STATISTICS IN SAS.

 FILENAME:  DESCRIPT.SAS
*********************************************/
/*Specify generic output using Options Formchar= */
options formchar="|----|+|---+=|-/\<>*";
title;

options nodate pageno=1;
title;

data pulse;
   infile "pulse.dat";
   input pulse1 pulse2 ran smokes sex height weight activity;
run;

proc format;
 value   sexfmt 1='Male' 2='Female';
 value   smkfmt 1='Yes' 2 = 'No';
run;

data pulse;
set pulse;
	label    pulse1  = "Resting pulse, rate per minute"
		    pulse2  = "Second pulse, rate per minute";
format   sex  sexfmt. smokes smkfmt.;
run;

/*PROC PRINT - DIFFERENT OPTIONS*/

proc print data=pulse;
run;
proc print data=pulse(obs=6);
run;

proc print data=pulse(firstobs=82 obs=85);
run;

proc print data=pulse;
  var ran height pulse1;
run;

proc print data=pulse;
  var sex -- activity;
run;

proc print data=pulse label noobs;
  var pulse1 sex -- activity;
run;

/*PROC CONTENTS*/

proc contents data=pulse;
run;

proc contents data=pulse varnum;
run;


/*PROC MEANS*/

proc means data=pulse;
run;

proc means data = pulse;
  var height weight pulse1;
run;

proc means data = pulse;
  var ran -- activity;
run;

proc means data = pulse;
    class ran;
run;

options nolabel;
proc means data = pulse;
    class ran activity;
run;

proc means data = pulse n nmiss mean std min max median;
  var pulse1 pulse2;
run;

/*95% Confidence Interval for Means*/
proc means data = pulse n mean clm;
  var pulse1 pulse2;
run;

proc means data = pulse n mean clm alpha = .01;
  var pulse1 pulse2;
run;

/*PROC FREQ*/

/*Oneway frequency tables*/
proc freq data = pulse;
   tables ran activity ;
run;

/*Twoway frequency table*/
proc freq data = pulse;
   tables sex * activity;
run;

proc freq data = pulse;
   tables sex * activity / nocol nopercent expected chisq;
run;


/*Table of Sex*Activity--stratified by RAN*/
proc freq data = pulse;
   tables ran* sex * activity / chisq ;
run;


/*PROC UNIVARIATE*/

proc univariate data = pulse;
   var pulse1 ;
run;

proc univariate data = pulse;
   var pulse2;
   id ran;
run;

proc univariate data = pulse ;
   histogram;
   qqplot / normal(mu=est sigma=est);
   var pulse1;
run;

proc univariate data=pulse;
  class ran;
  var pulse2;
  histogram;
run;


/*PROC GPLOT*/

/*Simple scatter plot*/
goptions reset=all;
goptions device=win target=winprtm;

proc gplot data = pulse;
   plot pulse2 * pulse1;
run; 

/*Fit a linear regression and display the line*/
goptions reset=all;
goptions device=win target=winprtm;
symbol1 value=dot color=black interpol=rl line=1;

proc gplot data = pulse;
   plot pulse2*pulse1;
run; quit;

/*Different symbols for groups of cases*/
goptions reset=all;
goptions device=win target=winprtm;

proc gplot data = pulse;
   plot pulse2*pulse1 = ran;
run; quit;

/*Regression Lines for different groups of cases*/
goptions reset=all;
goptions device=win target=winprtm;
symbol1 color=black value=star interpol=rl line=1;
symbol2 color=black value=dot interpol=rl line=2;

proc gplot data = pulse;
   plot pulse2*pulse1 = ran;
run; quit;
