/************************************************
 THIS COMMAND FILE ILLUSTRATES THE USE OF DO
 STATEMENTS IN THE DATA STEP.

 FILENAME: DOLOOP.SAS
*************************************************/
OPTIONS FORMCHAR="|----|+|---+=|-/\<>*";
title;
options nodate pageno=1;

/***************SIMPLE DO STATEMENTS**************/
data owen;
  infile "owen.dat";
  input fam_num childnum age sex race w_rank income_c height weight 
  hemo vit_c vit_a head_cir fatfold b_weight mot_age b_order 
  m_height f_height ;

  b_weight = b_weight*10;

  /*SET UP MISSING VALUE CODES*/
  if vit_a    = 99  then vit_a    = .;
  if head_cir = 99  then head_cir = .;
  if fatfold  = 99  then fatfold  = .;
  if mot_age  = 99  then mot_age  = .;
  if b_order  = 99  then b_order  = .;
  
  if height   = 999 then height   = .;
  if weight   = 999 then weight   = .;
  if b_weight = 999 then b_weight = .;
  if m_height = 999 then m_height = .;
  if f_height = 999 then f_height = .;

  /*USE DO GROUP, SO AGEGRP IS ONLY CREATED 
    FOR THOSE WITH MOT_AGE NOT= MISSING*/

  if mot_age not=. then do;
     if mot_age < 20 then agegrp = 1;
     if mot_age  >=   20 and mot_age  < 25 then agegrp = 2;
     if mot_age  >=   25 and mot_age  < 30 then agegrp = 3;
     if mot_age  >=   30 and mot_age  < 35 then agegrp = 4;
     if mot_age  >=   35 and mot_age  < 40 then agegrp = 5;
     if mot_age  >=   40 then agegrp  = 6;
  end;

run;

proc means data=owen;
run;

/******************NESTED DO LOOPS***********************/

data owen2;
  set owen;
 
  bmi = weight/(height/100)**2;

  if bmi not=. then do;
    if bmi <18 then do;
	 hibmi=0;
       bmicat=1;
    end;

    if 18 <bmi<= 21 then do;
	 hibmi=0;
	 bmicat=2;
    end;

    if 21<bmi<=24 then do;
	 hibmi  = 1;
	 bmicat = 3;
    end;

    if bmi >24 then do;
	 hibmi=1;
     bmicat=4;
    end;
  end;

run;

proc freq data=owen2;
  tables bmi hibmi bmicat;
run;

/**************ITERATIVE DO STATEMENTS*****************/

/**************USING A DO LOOP TO SET UP A DATA SET*****************/


data testdata;
  do X = 11 to 15;
  output;
  end;
run;
proc print;
run;


data testdata2;
 do trial = 1 to 3;
    do conc = 1 to 4;
      response = ranuni(24)*10;
      output;
    end;
 end;
run;
proc print;
run;


/**************USING A DO LOOP WITH DATE VALUES*****************/
data January;
  do date = "01JAN1990"D to "31JAN1990"D;
  format date date9.;
  output;
  end;
run;
proc print data=January;
run;



/**************USING A DO LOOP WITH CHARACTER VARIABLES 
               TO SET UP A DATA SET*****************/

data sample;
    length Season Region $12;
    do Season="Spring","Summer", "Fall", "Winter";
         do Region ="North", "East", "South", "Central", "West";
              sales=ceil(ranuni(5527)* 100000);
	        output;
         end;
    end;
	format sales dollar12.;
run;
proc print data=sample;
run;




/**************UNCLOSED DO LOOP ERROR*****************/

data testdata3;
 do trial = 1 to 3;
    do conc = 1 to 4;
    response = ranuni(24)*10;
	output;
 end;
run;
proc print data=testdata3;
run;

