
/********************************************
  THIS COMMAND FILE SHOWS HOW TO IDENTIFY
  DUPLICATE CASES AND WRITE THEM OUT

  FILENAME:  FIND_DUP.SAS
********************************************/

data clinic;
 input
   id  date :mmddyy8. sbp wt sideffct;
   format date mmddyy8.;
 cards;
131 4/2/95   129 150 1
131 4/2/95   129 150 1
131 5/5/95   118 154 1
131 6/1/95   119 152 0
131 7/10/95  116 151 1
131 8/14/95  111 153 0
131 8/14/95  111 153 0
105 7/15/95  120 188 0
105 8/22/95  147 185 1
105 7/15/95  145 180 1
105 12/20/95 129 185 0
222 3/14/95  159 201 0
222 7/19/95  158 218 1
222 8/17/95  148 222 1
  5 7/24/95  118 190 0
  5 8/28/95  114 185 0
  7 3/7/95   222 224 1
  7 4/18/95  201 201 0
222 10/13/95 145 215 1
222 5/29/95  155 207 0
222 10/13/95 160 219 0
;

proc sort data=clinic ;
   by id date;
run;

title "Original Data";
proc print data=clinic;
run;


/*ELIMINATE DUPLICATE DATES
  USING PROC SORT WITH THE
  NODUPKEY OPTION*/

proc sort data=clinic out=sort1 nodupkey;
  by id date;
run;

title "Sorted Data With Key Variables Removed";
proc print data=sort1;
run;

/*ELIMINATE DUPLICATE CASES USING PROC
  SORT WITH THE NODUPREC OPTION*/

proc sort data=clinic out=sort2 noduprec;
  by id date;
run;

title "Cases That Are Complete Duplicates Are Deleted";
proc print data=sort2;
run;

proc compare base=clinic compare=sort2 listbaseobs briefsummary;
  by id date;
run;

proc compare base=clinic compare=sort2 out=comparedat /*outall*/ noprint;
  by id date;
run;

title "Comparison Dataset";
proc print data=comparedat;
run;

/*Count how many cases for each ID and date combination*/
proc freq data=clinic noprint;
  tables id*date / out=tabdat;
run;

title "Identify Duplicate Cases";
proc print data=tabdat;
  where count>1;
run;

