/***************************************
 INTRO TO SAS 

 FILENAME: INTRO.SAS
***************************************/
/*Specify generic output using Options Formchar= */
options formchar="|----|+|---+=|-/\<>*";
title;

/*Instream Data*/
data test;
  input id sex $ testgrp age height weight;
  cards;
1 F 1 20 62 .
2 F 2 23 65 133
3 M 1 21 68 154
4 . 1 20 69 160
5 F 2 20 63 118
;
proc print data=test;
run;

/*READING RAW DATA FROM A FILE*/

data class;
	infile "class.dat";
	input lname $ sex $ age height sbp;
run;
proc print data=class;
run;

/*IMPORT AN EXCEL WORKSHEET*/

PROC IMPORT OUT= WORK.PULSE DATAFILE= "PULSE.XLS" DBMS=XLS REPLACE;
     SHEET="pulse"; 
RUN;

proc print data=pulse;
run;


/*MODIFY AN EXISTING DATA SET*/

data newclass;
  set class;
run;

data class2;
     set class;

     if height = 999 then height = .;
     if age >=  0 and age < 20 then agegrp = 1;
     if age >= 20 and age < 30 then agegrp = 2;
     if age >= 30 and age < 40 then agegrp = 3;
     if age >= 40 and age < 50 then agegrp = 4;
     if age >= 50 then agegrp = 5;

     loght = log(height);
run;
proc print data=class2;
run;

data pulse;
  set pulse;
  pulsediff = pulse2-pulse1;
  pulseavg = mean(pulse1,pulse2);
run;


/*PROCEDURES*/

proc print data=class2;
run;
proc ttest data=class2;
   class sex;
   var height;
run;

/*STEP BOUNDARIES*/

data class;
	infile "class.dat";
	input lname $ sex $ age height sbp;
run;

/*PROCEDURES*/
proc print data=class;
run;
proc ttest data=class;
   class sex;
   var height;
run;

/*TITLES AND FOOTNOTES*/

title "Descriptive Statistics for Numeric Variables";
title2 "Class2 Data Set";
footnote "Demo";
proc means data=class2; 
run;

title2 "Pulse Data Set";
proc means data=pulse;
run;

/*remove titles and footnotes*/
title;
footnote;


/*LABEL VARIABLES*/

data class;
	infile "class.dat";
	input lname $ sex $ age height sbp;

	label lname  = "Last Name"
		   age    = "Age in Years"
		   height = "Height(in)"
		   sbp    = "Systolic Blood Pressure(mm Hg)";
run;

proc print data=class label;
run;

/*COMMENTS*/

*this is a comment statement;
/*this is also a comment which may be inserted anywhere*/

/*
proc means data=class;
run;
proc print data=class;
run;
*/

proc ttest data=class;
  class sex /*comments can be included*/;
  var height;
run;

/*OPTIONS*/

options linesize=72;
options pagesize=54 linesize=72;

options formdlim = " ";   /*<-That's quote-blank-quote*/
options pageno=1;

/*GRAPHICS OPTIONS*/

goptions device=win target=winprtm;
