/******************************************************
 INTRODUCING MACRO VARIABLES AND MACRO PROGRAMS IN SAS.

 FILE = macros.sas
*******************************************************/
OPTIONS FORMCHAR="|----|+|---+=|-/\<>*";
options nodate pageno=1;
title;

data a;
  input dep1-dep4 ind1 ind2;
  cards;
1 0 1 1 24 23
0 0 1 0 22 32
1 1 1 0 22 20
0 1 0 1 31 40
0 1 0 1 37 45
0 1 0 1 39 50
0 1 0 1 31 40
1 1 0 0 46 43
0 0 0 1 37 23
1 1 0 0 22 57
0 1 0 1 14 25
1 1 0 0 24 29
1 0 1 1 20 19
0 0 1 0 24 30
1 1 1 0 27 40
0 1 0 1 35 25
;
run;
/*Use %let to assign a string to a macro variable */

%let all_inds = ind1 ind2;
%let all_deps = dep1 dep2 dep3 dep4;

/*The macro variable should be prefaced with a "&" when it is referenced in a proc */
proc means data=a;
var &all_inds;
run;

proc freq data=a;
tables &all_deps;
run;

/*Fitting models without using Macros*/
proc logistic data=a descending;
      model dep1 = ind1 ind2;
run;
proc logistic data=a descending;
      model dep2 = ind1 ind2;
run;

proc logistic data=a descending;
      model dep3 = ind1 ind2;
run;

options mprint;

/*the following macro makes use of a do loop, and demonstrates the %put statement*/

%macro many_logits1(num);
  %do i = 1 %to &num;
  title "The dependent variable is dep&i";
  proc logistic data=a descending;
      model dep&i = ind1 ind2;
    run;
  %end;
  %put &i;
%mend; 

/*run the program for the first three dependent variables, dep1-dep3 */

%many_logits1(3);

/*The following macro uses macro functions %scan(arg,i) and %eval*/

%macro many_logits2(dep_list);
  %let k=1;
  %let dep = %scan(&dep_list, &k);
  %do %while("&dep" NE "");
    title "The dependent variable is &dep";
    proc logistic data=a des;
      model &dep = ind1 ind2;
    run;
    %let k = %eval(&k + 1);
    %let dep = %scan(&dep_list, &k);
  %end;
%mend;

*run the program for the first three dv's;
%many_logits2(dep1 dep2 dep3)

*again, in reverse order;
%many_logits2(dep3 dep2 dep1)

/*Call the macro passing a global macro variable as the input*/

%many_logits2(&all_deps)

