
/**********************************************
 THIS FILE SHOWS HOW TO SET UP MISSING VALUE
 CODES IN SAS.

 FILENAME:  MISSING.SAS
***********************************************/
OPTIONS FORMCHAR="|----|+|---+=|-/\<>*";
options pageno=1 nodate;
title;

libname sasdata2 "C:\Users\kwelch\Desktop\sasdata2";
data owen;
   set sasdata2.owen;
run;

title "Owen Data. Missing Value Codes Have Not Been Fixed ";
proc means data=owen;
run;

/*SET UP MISSING VALUES IN A NEW DATA SET*/

data owen; 
set sasdata2.owen;
    /*set up missing value codes*/

  if vit_a    = 99 then vit_a    = .;
  if head_cir = 99 then head_cir = .;
  if fatfold  = 99 then fatfold  = .;
  if mot_age  = 99 then mot_age  = .;
  if b_order  = 99 then b_order  = .;

  if height   = 999 then height   = .;
  if weight   = 999 then weight   = .;
  if b_weight = 999 then b_weight = .;
  if m_height = 999 then m_height = .;
  if f_height = 999 then f_height = .;
 run;

title "Owen Data. Missing Value Codes Have Been Replaced by . ";
proc means data=owen n nmiss mean std min max;
run;


/**********************************
 EXAMPLE OF HOW TO SET UP SPECIAL
 MISSING VALUE CODES.
***********************************/

data one ;
  input score1 score2 score3;
  if score1 = 9 then score1 = .M;
  if score1 = 8 then score1 = .X;
  if score2 = 9 then score2 = .M;
  if score2 = 8 then score2 = .X;
  if score3 = 9 then score3 = .M;
  if score3 = 8 then score3 = .X;
  cards;
  2 3 4
  2 9 8
  1 4 8
  2 3 9
  1 3 2
  2 2 3
  8 1 3
  9 2 1
  1 1 2
  1 2 4
  3 1 2
  2 3 3
  ;
title "PROC PRINT OUTPUT";
proc print data=one;
run;
title "PROC MEANS OUTPUT: NOTE N FOR EACH VARIABLE"; 
proc means data=one;
run;
title "PROC FREQ OUTPUT-DEFAULT";
proc freq data=one;
  tables score1-score3;
run;


/*USE THE MISSPRINT OPTION TO
  SHOW MISSING VALUES, BUT NOT
  CALCULATE PERCENTAGES FOR THEM*/

title "Missing Values are displayed in the Output";
title2 "But Percentages are not Calculated for Them";
proc freq data=one ;
  tables score1-score3 / missprint ;
run;


/*USE THE MISSING OPTION TO SHOW
  MISSING VALUES, AND CALCULATE
  PERCENTAGES FOR THEM*/

title "Missing Values are displayed in the Output";
title2 "Percentages are calculated";
proc freq data=one ;
  tables score1-score3 / missing ;
run;


/*YOU CAN USE THE SPECIAL MISSING VALUE CODES
  TO SELECT CASES TO USE IN PROCEDURES*/

title "Printout of Missing Cases for Score1";
proc print data=one;
  where score1 < 0;
run;

title "Select Cases with Score1 = .M";
proc print data=one;
  where Score1 = .M;
run;
  
title "Select Cases with No Missing Values for Score1";
proc print data=one;
  where Score1 > .Z;
run;

/*CREATE A COMPLETE DATA SET WITH NO MISSING VALUES*/
data complete;
  set one;
  if nmiss(score1, score2, score3)=0;
run; 

title "Complete Data";
proc print data=complete;
run;

/*HOW TO SET UP SAS TO RECOGNIZE SPECIAL MISSING VALUES*/
data miss2;
  input id age weight;
  missing A B;
  cards;
1  22 145
2  25 122
3  28 A
4  26 B
5  20 103
6  29 .
7  A  118
8  32 182
9  A  203
10 21 B
  ;
proc print data=miss2;
run;
proc means data=miss2;
run;

/*MISSING VALUES FOR CHARACTER VARIABLES*/
data test problems;
  input name $ sex $ age;
  if sex = " " then output problems;
  else output test;
  cards;
Gene  M 62
Cyndi F 45
Alice . 51
Bob   M 55
    ;
proc print data=test;
  title "Test Data Set";
run;
proc print data=problems;
  title "Cases with Sex Missing";
run;

