
/**********************************************
 THIS COMMAND FILE SHOWS HOW TO COMBINE SAS
 DATASETS BY DOING ONE-TO-MANY MERGES.

 FILENAME:  one_to_many.sas
***********************************************/
title;
options nodate;
OPTIONS FORMCHAR="|----|+|---+=|-/\<>*";

/********************************************
 One-to-Many Merges for longitudinal data
*********************************************/
data time_varying;
  input ID @4 date :mmddyy10. SBP DBP;
  format date mmddyy10.;
cards;
4  1/9/2007  117 82
2  3/15/2007 111 74
2  4/25/2007 108 65
1  5/17/2007 145 94
1  11/22/2007 130 90
1  1/12/2008 120 80
3  1/22/2008 128 83
; 

title "Time Varying Data";
proc print data=time_varying;
run;

data one_per;
  input ID sex $ monbirth daybirth yearbirth;
  dob = mdy(monbirth,daybirth,yearbirth);
  format dob mmddyy10.;
  drop monbirth daybirth yearbirth;
cards;
3 M 12 1 1980
1 F 1 10 1978
2 F 5 15 1976
4 M 4 11 1981
5 F 7 17 1980
;

title "One-Per-Person Data";
proc print data=one_per;
run;


/*Merge the two data sets
  Be sure to sort first*/
proc sort data=time_varying;
by id date;
run;
proc sort data=one_per;
by id;
run;

data one_to_many;
  merge one_per(in=a)
        time_varying(in=b);
  by id;
  age = (date-dob)/365.25;
run;

title "One-to-Many Merged Data Set";
proc print data=one_to_many;
run;

/********************************************
 One-to-Many Merges for clustered data
*********************************************/
data classroom;
  input ClassID teacher_experience ;
cards;
1 20
2 12
3  6
;
data students;
  input ClassID studentID gender $ testscore;
cards;
1 1 M 78
1 2 F 92
1 3 M 94
1 4 M 91
2 1 F 87
2 2 F 93
2 3 F 89
2 3 M 92
3 1 F 99
3 2 M 94
3 3 M 88
;
proc sort data=classroom;
  by ClassID; run;
proc sort data=students;
  by ClassID StudentID; run;
data class_student;
  merge classroom students;
  by ClassID;
run;
title "Printout of Matched Class_Student Data";
proc print data=class_student;
run;

