/****************************************************
 THIS COMMAND FILE GIVES AN OVERVIEW OF SAS 
 DATA MANAGEMENT TASKS

 FILENAME: OVERVIEW.SAS
 ****************************************************/
OPTIONS FORMCHAR="|----|+|---+=|-/\<>*";

options nodate;
title;

data pulse;
   infile "pulse.dat" missover;
   input pulse1 pulse2 ran smokes sex height weight activity;
run;

/*MAKE A COPY OF A SAS DATA SET*/

data newpulse;
   set pulse;
run;

/*Making a Copy of a Permanent SAS Data Set*/

libname sasdata2 v9 "c:\temp\sasdata2";
data sasdata2.pulse;
   infile "pulse.dat" missover;
   input pulse1 pulse2 ran smokes sex height weight activity;
run;

data sasdata2.newpulse;
   set sasdata2.pulse;
run;


/*Creating subsets of data*/

data females;
   set pulse;
   if sex = 2;
run;

data males;
   set pulse;
   if sex = 1;
run;

/*Create two datasets with one data step*/

data males females;
   set pulse;
    if sex = 1 then output males;
    if sex = 2 then output females;
run;

/*Using a where statement to select cases for analysis*/

data marflt;
      infile "marflt.dat";
      input flight $ 1-4 @4 fltdate mmddyy6. 
      dest $ 18-20 passngrs 34-36 
      freight 43-45 capacity 46-48;
      format fltdate mmddyy8.;
      pctfull=(passngrs/capacity)*100;
run; 

proc print data=marflt;
    where dest = "LAX";
    var flight dest passngrs;
    title "Flights to Los Angeles";
run;

proc print data=marflt;
    where dest = " ";
    var flight dest passngrs;
    title "Missing Destination";
run;

proc print data=marflt;
    where pctfull < 30;
    var flight dest passngrs capacity pctfull;
    title "Flights Less than 30 Percent Full";
run;

proc print data=marflt;
    where pctfull between 25 and 30;
    title "Flights Between 25 and 30 Percent Full";
run;

proc print data=marflt;
    where (pctfull between 25 and 30) and (dest="DFW") ;
    title "Flights to Dallas-Fort Worth Between 25 and 30 Percent Full";
run;

proc print data=marflt;
    where passngrs = .;
    var flight dest passngrs;
    title "Number of Passengers is Missing";
run;

proc print data=marflt;
    where fltdate = "07MAR90"D;
    title "Flights on March 7th, 1990"; 
run;

proc print data=marflt;
    where fltdate between "07MAR90"D and "09MAR90"D;
    title "Flights Between March 7th and March 9th, 1990";
run;

proc print data=marflt;
    where fltdate = .;
    var flight dest fltdate;
    title "Missing Date";
run;


/*DELETE CASES FROM A DATA SET*/

data fixpulse;
   set pulse;
   if pulse1 > 95 then delete;
run;

/*Using Keep and Drop to control the variables in a data set*/

data sbp;
 input id drug sbp1 sbp2 wt sideffct;
 cards;
131 1 154 129 150 1
135 2 149 118 154 1
136 1 137 119 152 0
137 1 142 116 151 1
138 1 156 111 153 0
139 2 163 109 148 1
105 2 141 145 188 0
106 1 139 147 185 1
107 2 170 133 184 0
108 2 148 129 185 0
;

title "Printout of SBP Data Set";
proc print data=sbp;
run;

 /*KEEP STATEMENT*/
data sbp2;
  set sbp;
  sbpchg = sbp2-sbp1;
  keep id drug sbp1 sbp2 sbpchg;
run;

title "Printout of SBP2 Data";
proc print data=sbp2;
run;

 /*DROP STATEMENT*/

data sbp3;
  set sbp;
  drop wt sideffct;
run;

proc print data=sbp3;
   title "Printout of SBP3 Data";
run;

/*KEEP= DATA SET OPTION*/
/*USING KEEP= ON THE INPUT DATA SET*/

data sbp4;
   set sbp(keep=id drug sbp1 sbp2);
   avgsbp = mean(sbp1,sbp2);
run;
proc print data=sbp4;
  title "Printout of SBP4 Data";
run;

/*USING KEEP= ON THE OUTPUT DATA SET*/

data sbp5(keep=id drug avgsbp);
  set sbp;
  avgsbp = mean(sbp1,sbp2);
run;
proc print data=sbp5 (obs=5);
  title "Printout of SBP5 Data";
run;




