/************************************************
 THIS FILE READS IN THE RAW DATA FILE OWEN.CSV,
 DOES SOME RECODES, AND CREATES SOME DUMMY
 VARIABLES.

 FILENAME: RECODE.SAS
*************************************************/
OPTIONS FORMCHAR="|----|+|---+=|-/\<>*";
options nodate pageno=1 formdlim=" ";
title;

data owen;
  infile "owen.dat";
  input fam_num childnum age sex race w_rank income_c height weight 
  hemo vit_c vit_a head_cir fatfold b_weight mot_age b_order 
  m_height f_height ;

  if vit_a    = 99  then vit_a    = .;
  if head_cir = 99  then head_cir = .;
  if fatfold  = 99  then fatfold  = .;
  if mot_age  = 99  then mot_age  = .;
  if b_order  = 99  then b_order  = .;
  if height   = 999 then height   = .;
  if weight   = 999 then weight   = .;
  if b_weight = 999 then b_weight = .;
  if m_height = 999 then m_height = .;
  if f_height = 999 then f_height = .;

  /*Correct recode of mother's age into agegrp*/

  if mot_age  >=    0 and mot_age  < 20 then agegrp = 1;
  if mot_age  >=   20 and mot_age  < 25 then agegrp = 2;
  if mot_age  >=   25 and mot_age  < 30 then agegrp = 3;
  if mot_age  >=   30 and mot_age  < 35 then agegrp = 4;
  if mot_age  >=   35 and mot_age  < 40 then agegrp = 5;
  if mot_age  >=   40 then agegrp  = 6;

  /*Incorrect recode of mother's age*/

  if mot_age  < 20 then wrongage = 1;  
  if mot_age  >=   20 and mot_age  < 25 then wrongage = 2;
  if mot_age  >=   25 and mot_age  < 30 then wrongage = 3;
  if mot_age  >=   30 and mot_age  < 35 then wrongage = 4;
  if mot_age  >=   35 and mot_age  < 40 then wrongage = 5;
  if mot_age  >=   40 then wrongage  = 6;

/*Create dummy variable for birth weight < 2500 grams*/

  b_weight = 10*b_weight;
  if b_weight > 0 and b_weight < 2500 then lowbwt = 1;
  if b_weight >= 2500 then lowbwt = 0;  
run;


proc means data=owen;
run;

/*CHECK THE VALUES OF THE RECODES*/
proc means data=owen;
  class agegrp;
  var mot_age;
run;

/*USE PROC FREQ TO CHECK ON NEW VARIABLES*/

proc freq data=owen;
  tables wrongage agegrp;
run;


/*CREATE DUMMY VARIABLES*/

data newowen;
   set owen;
 if agegrp ne . then do;
    age1 = (agegrp=1);
	age2 = (agegrp=2);
	age3 = (agegrp=3);
	age4 = (agegrp=4);
	age5 = (agegrp=5);
	age6 = (agegrp=6);
  end;
  male  = (sex=1); 
  white = (race=1);
run;
proc print data=newowen(obs=15) ;
 var mot_age agegrp age1-age6 sex male race white;
 title "Checking on Dummy Variables";
run;

/*USING DUMMY VARIABLES IN A REGRESSION MODEL*/

title "Regression Model Using Dummy Variables";
proc reg data=newowen;
  model b_weight = age2 age3 age4 age5 age6;
run; quit;


/*USE RECODES IN SAS TO FIX DATA*/
data fixup;
  set owen;
  if fam_num=5911 and childnum=1 then do;
     b_weight=3025;
     m_height=162;
  end;
  if fatfold = 42 then fatfold=24;
run;
proc print;
  where fam_num=5911 and childnum=1;
  var fam_num childnum b_weight m_height;
  title "Printout of One Child's Data for Checking";
run;
