/*****************************************
 SAS 9.2 and 9.3 Statistical Graphics Examples
 filename: sgraphics.sas
******************************************/
/*Option to make the output look nice, if you
  use Courier or another non-SAS font*/
OPTIONS FORMCHAR="|----|+|---+=|-/\<>*";

/*Enable the ODS Graphics Editor*/
ods listing sge = on;

/************************************************
  Change the path to mylib to the folder where
  you have stored your SAS datasets,
  Employee.sas7bdat, and Autism.sas7bdat
  e.g., for a folder called sasdata2 on the desktop:
  libname mylib "C:\Users\kwelch\Desktop\SASDATA2";
*************************************************/

libname mylib "C:\Users\kwelch\Desktop\SASDATA2" ;

/*Boxplots*/
title "Boxplot";
title2 "No Categories";
proc sgplot data=mylib.employee;
  vbox salary;
run; 


title "Boxplot";
title2 "Category=Gender";
proc sgplot data=mylib.employee;
  vbox salary/ category=gender;
run; 

title "Boxplot with Panels";
proc sgpanel data=mylib.employee;
  panelby jobcat / rows=1 columns=3 ;
  vbox salary / category= gender;
run;

/*Barcharts*/
title "Vertical Bar Chart";
proc sgplot data=mylib.employee;
  vbar jobcat ;
run;

title "Vertical Bar Chart";
title2 "Clustered by Gender";
proc sgplot data=mylib.employee;
  vbar jobcat /group=Gender groupdisplay=cluster ;
run;

title "BarChart with Mean and Standard Deviation";
proc sgplot data=mylib.employee;
  vbar jobcat / response=salary limitstat = stddev
  limits = upper stat=mean;
run;

/*Data setup for barchart showing proportions*/

data afifi;
  set mylib.afifi;
  if survive=1 then died=0;
  if survive=3 then died=1;
  if shoktype=2 then shock=0;
  if shoktype >2 then shock=1;
run;
proc format;
  value shokfmt 2="Non-Shock"
                3="Hypovolemic"  
                4="Cardiogenic"
                5="Bacterial"
                6="Neurogenic"           
                7="Other";        
run;

title "Barchart of Proportion Died for each Shock Type";
proc sgplot data=afifi;
  vbar shoktype / response=died stat=mean;
  format shoktype shokfmt.;
run;


title "BarChart Paneled by Gender";
proc sgpanel data=mylib.employee;
   panelby gender ;
   vbar jobcat / response=salary limitstat = stddev
      limits = upper stat=mean;
run;

/*Histograms*/
/*use scale=proportion, count, or percent(default)*/

title "Histogram";
proc sgplot data=mylib.employee;
  histogram salary ;
run; 

title "Histogram With Density Overlaid";
proc sgplot data=mylib.employee;
  histogram salary ;
  density salary;
  density salary / type=kernel;
  keylegend / location = inside position = topright;
  format salary dollar10.; 
run;

title "Paneled Histogram";
title2 "Exclude Custodial";
proc sgpanel data=mylib.employee;
  where jobcat not=2;
  panelby gender jobcat/  rows=2 columns = 2;
  histogram salary / scale=proportion; 
run;


/*Scatterplots*/
title "Scatterplot";
proc sgplot data=mylib.employee;
  scatter x=salbegin y=salary;
run;

title "Scatterplot with Regression Line";
title2 "Clerical Only";
proc sgplot data=mylib.employee;
  where jobcat=1;
  scatter x=prevexp y=salary / group=gender ;
  reg x=prevexp y=salary / nomarkers cli clm;
run;

title "Scatterplot with Regression Line";
title2 "Separate Lines for Females and Males";
proc sgplot data=mylib.employee;
  where jobcat=1;
  reg x=prevexp y=salary / group=gender;
run;


/*Scatterplot matrix*/
title "Scatterplot Matrix"; 
title2 "Clerical Employees";
proc sgscatter data=mylib.employee;
  where jobcat=1;
  matrix salbegin salary jobtime prevexp / group=gender
                   diagonal=(histogram kernel);
run;

/*Series Plots*/
PROC IMPORT OUT= WORK.autism 
            DATAFILE= "autism.csv" 
            DBMS=CSV REPLACE;
     GETNAMES=YES;
     DATAROW=2; 
RUN;

title "Spaghetti Plots for Each Child";
proc sgpanel data=autism;
  panelby sicdegp /columns=3;
  series x=age y=vsae / group=Childid 
  markers  legendlabel=" " lineattrs=(pattern=1 color=black); 
run;


/*Using Formats to make graphs more readable*/
proc format;
   value jobcat 1="Clerical"
                2="Custodial"
			    3="Manager";
   value $Gender "f"="Female"
                 "m"="Male";
run;

ods listing style=journal;
title "Boxplot with Panels";
proc sgpanel data=mylib.employee;
  panelby jobcat / rows=1 columns=3 novarname;
  vbox salary / category= gender ;
  format gender $gender. jobcat jobcat.;
run;

