/****************************************
 THIS COMMAND FILE SHOWS HOW TO SORT
 DATA BY GROUPS, AND GET ANALYSES BY 
 GROUPS.

 FILENAME:  SORT.SAS
****************************************/
 OPTIONS FORMCHAR="|----|+|---+=|-/\<>*";

data pulse;
   infile "pulse.dat";
   input pulse1 pulse2 ran smokes sex height weight activity;
 run;

/*SORT BY ONE VARIABLE*/
proc sort data=pulse;
       by sex;
run;
title "Separate regression model for males and females";
proc reg;
      by sex;
      model pulse2=pulse1 ran;
run;

/*SORT BY MORE THAN ONE VARIABLE*/

proc sort data=pulse;
     by sex ran;
run;
options nolabel;
proc means data=pulse;
     by  sex ran;
run;


/*CREATING A NEW DATASET FROM PROC SORT*/

data clinic;
 input
   id group date :mmddyy8. sbp wt sideffct;
   format date mmddyy8.;
   cards;
131 1 4/2/95 129 150 1
131 1 4/2/95 129 150 1
131 1 5/5/95 118 154 1
131 1 6/1/95 119 152 0
131 1 7/10/95 116 151 1
131 1 8/14/95 111 153 0
131 1 8/14/95 111 153 0
105 2 7/15/95 145 188 0
105 2 8/22/95 147 185 1
105 2 7/15/95 145 188 1
105 2 12/20/95 129 185 0
222 1 3/14/95 159 201 0
222 1 7/19/95 158 218 1
222 1 8/17/95 148 222 1
5 2 7/24/95 118 190 0
5 2 8/28/95 114 185 0
7 1 3/7/95 222 224 1
7 1 4/18/95 201 201 0
222 1 10/13/95 145 215 1
222 1 5/29/95 155 207 0
222 1 10/13/95 160 219 0
;
proc sort data=clinic out=sortclin;
   by group id date;
run;
title "Data Set Sorted by Group, ID and Date";
proc print data=sortclin;
run;

/*CAPTURE THE FIRST OBS FOR A SET OF CASES WITH DUPCLICATE KEY VALUES*/

proc sort data=clinic out=sortclin nodupkey;
   by id date;
run;

/*CAPTURE THE DUPLICATE CASES INTO A DATASET CALLED DUPDAT*/
proc sort data=clinic out=sortclin nodupkey dupout=dupDAT;
   by id date;
run;

title "Printout of Data with Duplicates Removed";
proc print data=sortclin;
run;


/*PUT OBS ALL DUPS INTO SORTCLIN2
  PUT ALL UNIQUE OBS INTO UNIQUEDAT*/
proc sort data=clinic out=sortclin2 nouniquekey uniqueout=uniquedat;
  by id date;
run;

title "Cases with Unique Values Only";
title2 "These cases had no duplicates in the first place";
proc print data=uniqueDAT;
run;
title "Cases with Duplicate Values (none of thse are unique)";
title2 "These are the duplicates";
proc print data=sortclin2;
run;

title "Duplicates";
proc print data=dups;
run;


/*GET RID OF ONLY CASES THAT ARE IDENTICAL FOR ALL VARIABLES*/

proc sort data=clinic out=sortclin2 noduprec; 
   by id date; 
run;

proc print data=sortclin2;
  title "Printout of Data with No Cases That are Complete Duplicates";
run;
