/**********************************************
 THIS COMMAND FILE CARRIES OUT SOME BASIC
 STATISTICAL TESTS ON THE AFIFI DATA SET.

FILENAME: STATISTICS.SAS
***********************************************/
OPTIONS FORMCHAR="|----|+|---+=|-/\<>*";
OPTIONS PAGENO=1;

LIBNAME SASDATA2 "C:\Users\kwelch\Desktop\sasdata2";


DATA AFIFI;
	SET SASDATA2.AFIFI;

    IF SHOKTYPE=2 THEN SHOCK=1;
    IF SHOKTYPE IN (3,4,5,6,7) THEN SHOCK=2;
    IF SURVIVE=1 THEN DIED=0;
    IF SURVIVE=3 THEN DIED=1;
    SBPDIFF=SBP2-SBP1;
    LABEL SHOCK="Binary Shock"; 
RUN;

PROC FORMAT;
    VALUE SEXFMT   1="1: Male" 2="2: Female" ;
    VALUE SURVFMT  1="1: Lived" 3="3: Died" ;
    VALUE SHKTYFMT 2="2: Non-Shock" 
	               3="3: Hypovolemic"
			       4="4: Cardiogenic"
			       5="5: Bacterial"
			       6="6: Neurogenic"
			       7="7: Other";
    VALUE SHOCKFMT 1="1: No shock" 2="2: Shock" ;
RUN;

PROC DATASETS LIB=WORK;
    MODIFY AFIFI;
    FORMAT SEX SEXFMT. SURVIVE SURVFMT. SHOKTYPE SHKTYFMT. SHOCK SHOCKFMT.;
RUN;

PROC CONTENTS DATA=AFIFI VARNUM;
RUN;

TITLE1 "INTRO SAS WORKSHOP";
TITLE2 "AFIFI ANALYSIS";
TITLE3 "DESCRIPTIVE STATISTICS";
PROC MEANS DATA=AFIFI;
RUN;

TITLE3 "FREQUENCY TABLES FOR SELECTED VARIABLES" ; 
PROC FREQ DATA=AFIFI;
    TABLES SEX SURVIVE SEX SHOKTYPE SHOCK ;
RUN;

TITLE3 "CROSS TABULATIONS FOR SURVIVAL AND SHOCK TYPE" ; 
PROC FREQ DATA=AFIFI;
    TABLES SHOCK*SURVIVE/CHISQ EXPECTED RELRISK;
RUN;

TITLE3 "HISTOGRAMS, NORMAL Q-Q PLOTS" ; 
PROC UNIVARIATE DATA=AFIFI;
    ID IDNUM;
    VAR SBP1 URINE1 ;
    HISTOGRAM;
	QQPLOT / NORMAL(MU=EST SIGMA=EST);
RUN;

TITLE3 "INDEPENDENT SAMPLES T-TEST FOR SELECTED VARIABLES";
PROC TTEST DATA=AFIFI;
    CLASS SURVIVE ;
    VAR SBP1 HEART1 CARDIAC1 MAP1;
RUN;

TITLE3 "PAIRED T-TEST FOR SBP1 VS. SBP2";
PROC TTEST DATA=AFIFI;
    PAIRED SBP2*SBP1;
FOOTNOTE "T-TEST IS FOR NULL HYPOTHESIS THAT MEAN OF THE DIFFERENCES EQUALS ZERO";
RUN;

PROC SORT DATA=AFIFI;
    BY SURVIVE ; 
RUN;

TITLE4 "SEPARATELY FOR THOSE WHO SURVIVED AND THOSE WHO DIED"; 
PROC TTEST DATA=AFIFI;
    BY SURVIVE;
    PAIRED SBP2*SBP1;
RUN;

TITLE3 "CORRELATIONS" ;
PROC CORR DATA=AFIFI NOMISS;
    VAR SBP2 CARDIAC1 HEART1 HGB1 MAP1 ;
    FOOTNOTE ;
RUN;

ods graphics on;
TITLE3 "REGRESSION ANALYSIS WITH DIAGNOSTIC PLOTS";
TITLE4 "AND ANALYSIS OF RESIDUALS"; 
PROC REG DATA=AFIFI;
    MODEL SBP2= CARDIAC1 HEART1 HGB1 URINE1 MAP1;
RUN;QUIT;
ods graphics off;


TITLE3 "ONEWAY ANALYSIS OF VARIANCE";
TITLE4 "WITH TUKEY MULTIPLE COMPARISON TECHNIQUE"; 
PROC GLM DATA=AFIFI;
    CLASS SHOKTYPE;
    MODEL SBP1=SHOKTYPE;
    MEANS SHOKTYPE/ TUKEY NOSORT;
RUN; QUIT;

ods graphics on;
TITLE3 "LOGISTIC REGRESSION"; 
PROC LOGISTIC DATA=AFIFI PLOTS=(ROC EFFECT);
   CLASS SHOKTYPE / PARAM=REF REF=FIRST;
   MODEL DIED(EVENT="1") = MAP1 SHOCK/ RL RSQUARE LACKFIT;
   UNITS MAP1=1 10;
RUN;
ods graphics off;

ods graphics on;
TITLE3 "LOGISTIC REGRESSION"; 
PROC LOGISTIC DATA=AFIFI PLOTS=(ROC EFFECT);
   CLASS SHOKTYPE / PARAM=REF REF=FIRST;
   MODEL DIED(EVENT="1") = SBP1 CARDIAC1 SHOKTYPE/ RL RSQUARE LACKFIT;
   UNITS SBP1=1 10 CARDIAC1=1;
RUN;
ods graphics off;

