/**********************************************
 THIS COMMAND FILE SHOWS HOW TO CREATE SUMMARY
 STATISTICS FOR A SAS DATASET.

 FILENAME:  SUMMARY.SAS
************************************************/
OPTIONS FORMCHAR="|----|+|---+=|-/\<>*";
options nodate;
title;

/*CREATE THE DATA SET*/
data kids;
     input school $ name  $ sex  age mathscor engscor;
     cards;
Dicken   Tom      1 12 62 128
Dicken   Sarah    0 13 63 118
Dicken   Bob      1 13 57 116
Dicken   Joe      1 11 59 105
Dicken   Molly    0 13 64 129
Dicken   Sharice  0 11 53 109
Mack     Harry    1 12 53 102
Mack     Mary     0 12 49  97
Mack     William  1 13 66 139
Mack     Ellen    0 13  . 117
Bach     John     1 11 57 119
Bach     Carol    0 13 62 126
Bach     Richard  1 11 55 115
Bach     Chris    1 12 59 102
Bach     Mark     1 13 65  .
Bach     Steve    1 13 62 120
King     Chris    0 12 59 102
King     Claire   0 13  . 126
King     Lynn     0 12 55 114
     ;

/*SORT THE DATA*/
proc sort data=kids;
   by school;
run;

proc print data=kids;
   title "Printout of Original Data Set Sorted by School";
run;

/*GET SUMMARY STATS AND SAVE IN SCHOOLDAT*/

proc means data=kids noprint;
   by school;
   output out=schooldat mean(mathscor)=meanmath mean(engscor)=meaneng
     mean(age)=meanage n(mathscor)=nmath n(engscor)=neng n(age)=nage sum(sex)=males;
run;

proc print data=schooldat;
   title "Printout of Summary Data Set";
run;

/*CALCULATE NEW VARIABLES FOR THE SCHOOL DATA*/

 data school2;
   set schooldat;
   females = _freq_ - males;
   pctmale = (males/_freq_)*100;
   pctfem  = (females/_freq_)*100;
   totkids = _freq_;
   drop _freq_;
run;
proc print data=school2;
  title "Printout of Revised Summary Data Set";
run;


/*GET SUMMARY STATS BY TWO GROUPING VARIABLES*/

proc sort data=kids;
   by school sex;
run;

proc means data=kids noprint ;
   by school sex;
   output out=schoolsex mean(mathscor)=meanmath mean(engscor)=meaneng
     mean(age)=meanage n(mathscor)=nmath n(engscor)=neng n(age)=nage;
run;
proc print data=schoolsex;
   title "Summary Data for Each School and Sex";
run;

/*DO ALL OF THE SUMMARIES, ETC. IN PERMANENT SAS DATA SETS*/
libname sasdata2 "C:\Users\kwelch\Desktop\sasdata2";

proc sort data=kids;
   by school;
run;

proc means data=kids noprint;
   by school;
   output out=sasdata2.schooldat mean(mathscor)=meanmath mean(engscor)=meaneng
     mean(age)=meanage n(mathscor)=nmath n(engscor)=neng n(age)=nage sum(sex)=males;
run;

data sasdata2.school2;
   set sasdata2.schooldat;
   females = _freq_ - males;
   pctmale = (males/_freq_)*100;
   pctfem  = (females/_freq_)*100;
   totkids = _freq_;
   drop _freq_;
run;

/*Merging Summary Statistics with the Original Data Set*/

data schoolkid;
   merge kids school2;
   by school;
run;

proc print data=schoolkid;
   title "Printout of Merged Data Set";
run;
